# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class OverrideAccounts(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'AccountType',
        'subtype': 'AccountSubtype',
        'starting_balance': 'float',
        'force_available_balance': 'float',
        'currency': 'str',
        'meta': 'Meta',
        'numbers': 'Numbers',
        'transactions': 'list[TransactionOverride]',
        'identity': 'OwnerOverride',
        'liability': 'LiabilityOverride',
        'inflow_model': 'InflowModel'
    }

    attribute_map = {
        'type': 'type',
        'subtype': 'subtype',
        'starting_balance': 'starting_balance',
        'force_available_balance': 'force_available_balance',
        'currency': 'currency',
        'meta': 'meta',
        'numbers': 'numbers',
        'transactions': 'transactions',
        'identity': 'identity',
        'liability': 'liability',
        'inflow_model': 'inflow_model'
    }

    def __init__(self, type=None, subtype=None, starting_balance=None, force_available_balance=None, currency=None, meta=None, numbers=None, transactions=None, identity=None, liability=None, inflow_model=None, local_vars_configuration=None):  # noqa: E501
        """OverrideAccounts - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._subtype = None
        self._starting_balance = None
        self._force_available_balance = None
        self._currency = None
        self._meta = None
        self._numbers = None
        self._transactions = None
        self._identity = None
        self._liability = None
        self._inflow_model = None
        self.discriminator = None

        self.type = type
        self.subtype = subtype
        if starting_balance is not None:
            self.starting_balance = starting_balance
        if force_available_balance is not None:
            self.force_available_balance = force_available_balance
        if currency is not None:
            self.currency = currency
        if meta is not None:
            self.meta = meta
        if numbers is not None:
            self.numbers = numbers
        if transactions is not None:
            self.transactions = transactions
        if identity is not None:
            self.identity = identity
        if liability is not None:
            self.liability = liability
        if inflow_model is not None:
            self.inflow_model = inflow_model

    @property
    def type(self):
        """Gets the type of this OverrideAccounts.  # noqa: E501


        :return: The type of this OverrideAccounts.  # noqa: E501
        :rtype: AccountType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this OverrideAccounts.


        :param type: The type of this OverrideAccounts.  # noqa: E501
        :type type: AccountType
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def subtype(self):
        """Gets the subtype of this OverrideAccounts.  # noqa: E501


        :return: The subtype of this OverrideAccounts.  # noqa: E501
        :rtype: AccountSubtype
        """
        return self._subtype

    @subtype.setter
    def subtype(self, subtype):
        """Sets the subtype of this OverrideAccounts.


        :param subtype: The subtype of this OverrideAccounts.  # noqa: E501
        :type subtype: AccountSubtype
        """
        if self.local_vars_configuration.client_side_validation and subtype is None:  # noqa: E501
            raise ValueError("Invalid value for `subtype`, must not be `None`")  # noqa: E501

        self._subtype = subtype

    @property
    def starting_balance(self):
        """Gets the starting_balance of this OverrideAccounts.  # noqa: E501

        If provided, the account will start with this amount as the `current_balance`.   # noqa: E501

        :return: The starting_balance of this OverrideAccounts.  # noqa: E501
        :rtype: float
        """
        return self._starting_balance

    @starting_balance.setter
    def starting_balance(self, starting_balance):
        """Sets the starting_balance of this OverrideAccounts.

        If provided, the account will start with this amount as the `current_balance`.   # noqa: E501

        :param starting_balance: The starting_balance of this OverrideAccounts.  # noqa: E501
        :type starting_balance: float
        """

        self._starting_balance = starting_balance

    @property
    def force_available_balance(self):
        """Gets the force_available_balance of this OverrideAccounts.  # noqa: E501

        If provided, the account will always have this amount as its `available_balance`, regardless of current balance or changes in transactions over time.  # noqa: E501

        :return: The force_available_balance of this OverrideAccounts.  # noqa: E501
        :rtype: float
        """
        return self._force_available_balance

    @force_available_balance.setter
    def force_available_balance(self, force_available_balance):
        """Sets the force_available_balance of this OverrideAccounts.

        If provided, the account will always have this amount as its `available_balance`, regardless of current balance or changes in transactions over time.  # noqa: E501

        :param force_available_balance: The force_available_balance of this OverrideAccounts.  # noqa: E501
        :type force_available_balance: float
        """

        self._force_available_balance = force_available_balance

    @property
    def currency(self):
        """Gets the currency of this OverrideAccounts.  # noqa: E501

        ISO-4217 currency code. If provided, the account will be denominated in the given currency. Transactions will also be in this currency by default.  # noqa: E501

        :return: The currency of this OverrideAccounts.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this OverrideAccounts.

        ISO-4217 currency code. If provided, the account will be denominated in the given currency. Transactions will also be in this currency by default.  # noqa: E501

        :param currency: The currency of this OverrideAccounts.  # noqa: E501
        :type currency: str
        """

        self._currency = currency

    @property
    def meta(self):
        """Gets the meta of this OverrideAccounts.  # noqa: E501


        :return: The meta of this OverrideAccounts.  # noqa: E501
        :rtype: Meta
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """Sets the meta of this OverrideAccounts.


        :param meta: The meta of this OverrideAccounts.  # noqa: E501
        :type meta: Meta
        """

        self._meta = meta

    @property
    def numbers(self):
        """Gets the numbers of this OverrideAccounts.  # noqa: E501


        :return: The numbers of this OverrideAccounts.  # noqa: E501
        :rtype: Numbers
        """
        return self._numbers

    @numbers.setter
    def numbers(self, numbers):
        """Sets the numbers of this OverrideAccounts.


        :param numbers: The numbers of this OverrideAccounts.  # noqa: E501
        :type numbers: Numbers
        """

        self._numbers = numbers

    @property
    def transactions(self):
        """Gets the transactions of this OverrideAccounts.  # noqa: E501

        Specify the list of transactions on the account.  # noqa: E501

        :return: The transactions of this OverrideAccounts.  # noqa: E501
        :rtype: list[TransactionOverride]
        """
        return self._transactions

    @transactions.setter
    def transactions(self, transactions):
        """Sets the transactions of this OverrideAccounts.

        Specify the list of transactions on the account.  # noqa: E501

        :param transactions: The transactions of this OverrideAccounts.  # noqa: E501
        :type transactions: list[TransactionOverride]
        """

        self._transactions = transactions

    @property
    def identity(self):
        """Gets the identity of this OverrideAccounts.  # noqa: E501


        :return: The identity of this OverrideAccounts.  # noqa: E501
        :rtype: OwnerOverride
        """
        return self._identity

    @identity.setter
    def identity(self, identity):
        """Sets the identity of this OverrideAccounts.


        :param identity: The identity of this OverrideAccounts.  # noqa: E501
        :type identity: OwnerOverride
        """

        self._identity = identity

    @property
    def liability(self):
        """Gets the liability of this OverrideAccounts.  # noqa: E501


        :return: The liability of this OverrideAccounts.  # noqa: E501
        :rtype: LiabilityOverride
        """
        return self._liability

    @liability.setter
    def liability(self, liability):
        """Sets the liability of this OverrideAccounts.


        :param liability: The liability of this OverrideAccounts.  # noqa: E501
        :type liability: LiabilityOverride
        """

        self._liability = liability

    @property
    def inflow_model(self):
        """Gets the inflow_model of this OverrideAccounts.  # noqa: E501


        :return: The inflow_model of this OverrideAccounts.  # noqa: E501
        :rtype: InflowModel
        """
        return self._inflow_model

    @inflow_model.setter
    def inflow_model(self, inflow_model):
        """Sets the inflow_model of this OverrideAccounts.


        :param inflow_model: The inflow_model of this OverrideAccounts.  # noqa: E501
        :type inflow_model: InflowModel
        """

        self._inflow_model = inflow_model

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OverrideAccounts):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OverrideAccounts):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class StandaloneInvestmentTransactionType(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'buy': 'str',
        'sell': 'str',
        'cancel': 'str',
        'cash': 'str',
        'fee': 'str',
        'transfer': 'str'
    }

    attribute_map = {
        'buy': 'buy',
        'sell': 'sell',
        'cancel': 'cancel',
        'cash': 'cash',
        'fee': 'fee',
        'transfer': 'transfer'
    }

    def __init__(self, buy=None, sell=None, cancel=None, cash=None, fee=None, transfer=None, local_vars_configuration=None):  # noqa: E501
        """StandaloneInvestmentTransactionType - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._buy = None
        self._sell = None
        self._cancel = None
        self._cash = None
        self._fee = None
        self._transfer = None
        self.discriminator = None

        if buy is not None:
            self.buy = buy
        if sell is not None:
            self.sell = sell
        if cancel is not None:
            self.cancel = cancel
        if cash is not None:
            self.cash = cash
        if fee is not None:
            self.fee = fee
        if transfer is not None:
            self.transfer = transfer

    @property
    def buy(self):
        """Gets the buy of this StandaloneInvestmentTransactionType.  # noqa: E501

        Buying an investment  # noqa: E501

        :return: The buy of this StandaloneInvestmentTransactionType.  # noqa: E501
        :rtype: str
        """
        return self._buy

    @buy.setter
    def buy(self, buy):
        """Sets the buy of this StandaloneInvestmentTransactionType.

        Buying an investment  # noqa: E501

        :param buy: The buy of this StandaloneInvestmentTransactionType.  # noqa: E501
        :type buy: str
        """

        self._buy = buy

    @property
    def sell(self):
        """Gets the sell of this StandaloneInvestmentTransactionType.  # noqa: E501

        Selling an investment  # noqa: E501

        :return: The sell of this StandaloneInvestmentTransactionType.  # noqa: E501
        :rtype: str
        """
        return self._sell

    @sell.setter
    def sell(self, sell):
        """Sets the sell of this StandaloneInvestmentTransactionType.

        Selling an investment  # noqa: E501

        :param sell: The sell of this StandaloneInvestmentTransactionType.  # noqa: E501
        :type sell: str
        """

        self._sell = sell

    @property
    def cancel(self):
        """Gets the cancel of this StandaloneInvestmentTransactionType.  # noqa: E501

        A cancellation of a pending transaction  # noqa: E501

        :return: The cancel of this StandaloneInvestmentTransactionType.  # noqa: E501
        :rtype: str
        """
        return self._cancel

    @cancel.setter
    def cancel(self, cancel):
        """Sets the cancel of this StandaloneInvestmentTransactionType.

        A cancellation of a pending transaction  # noqa: E501

        :param cancel: The cancel of this StandaloneInvestmentTransactionType.  # noqa: E501
        :type cancel: str
        """

        self._cancel = cancel

    @property
    def cash(self):
        """Gets the cash of this StandaloneInvestmentTransactionType.  # noqa: E501

        Activity that modifies a cash position  # noqa: E501

        :return: The cash of this StandaloneInvestmentTransactionType.  # noqa: E501
        :rtype: str
        """
        return self._cash

    @cash.setter
    def cash(self, cash):
        """Sets the cash of this StandaloneInvestmentTransactionType.

        Activity that modifies a cash position  # noqa: E501

        :param cash: The cash of this StandaloneInvestmentTransactionType.  # noqa: E501
        :type cash: str
        """

        self._cash = cash

    @property
    def fee(self):
        """Gets the fee of this StandaloneInvestmentTransactionType.  # noqa: E501

        Fees on the account, e.g. commission, bookkeeping, options-related.  # noqa: E501

        :return: The fee of this StandaloneInvestmentTransactionType.  # noqa: E501
        :rtype: str
        """
        return self._fee

    @fee.setter
    def fee(self, fee):
        """Sets the fee of this StandaloneInvestmentTransactionType.

        Fees on the account, e.g. commission, bookkeeping, options-related.  # noqa: E501

        :param fee: The fee of this StandaloneInvestmentTransactionType.  # noqa: E501
        :type fee: str
        """

        self._fee = fee

    @property
    def transfer(self):
        """Gets the transfer of this StandaloneInvestmentTransactionType.  # noqa: E501

        Activity which modifies a position, but not through buy/sell activity e.g. options exercise, portfolio transfer  # noqa: E501

        :return: The transfer of this StandaloneInvestmentTransactionType.  # noqa: E501
        :rtype: str
        """
        return self._transfer

    @transfer.setter
    def transfer(self, transfer):
        """Sets the transfer of this StandaloneInvestmentTransactionType.

        Activity which modifies a position, but not through buy/sell activity e.g. options exercise, portfolio transfer  # noqa: E501

        :param transfer: The transfer of this StandaloneInvestmentTransactionType.  # noqa: E501
        :type transfer: str
        """

        self._transfer = transfer

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StandaloneInvestmentTransactionType):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StandaloneInvestmentTransactionType):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class InstitutionsGetRequestOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'products': 'list[Products]',
        'routing_numbers': 'list[str]',
        'oauth': 'bool',
        'include_optional_metadata': 'bool'
    }

    attribute_map = {
        'products': 'products',
        'routing_numbers': 'routing_numbers',
        'oauth': 'oauth',
        'include_optional_metadata': 'include_optional_metadata'
    }

    def __init__(self, products=None, routing_numbers=None, oauth=None, include_optional_metadata=None, local_vars_configuration=None):  # noqa: E501
        """InstitutionsGetRequestOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._products = None
        self._routing_numbers = None
        self._oauth = None
        self._include_optional_metadata = None
        self.discriminator = None

        if products is not None:
            self.products = products
        if routing_numbers is not None:
            self.routing_numbers = routing_numbers
        if oauth is not None:
            self.oauth = oauth
        if include_optional_metadata is not None:
            self.include_optional_metadata = include_optional_metadata

    @property
    def products(self):
        """Gets the products of this InstitutionsGetRequestOptions.  # noqa: E501

        Filter the Institutions based on which products they support.   # noqa: E501

        :return: The products of this InstitutionsGetRequestOptions.  # noqa: E501
        :rtype: list[Products]
        """
        return self._products

    @products.setter
    def products(self, products):
        """Sets the products of this InstitutionsGetRequestOptions.

        Filter the Institutions based on which products they support.   # noqa: E501

        :param products: The products of this InstitutionsGetRequestOptions.  # noqa: E501
        :type products: list[Products]
        """

        self._products = products

    @property
    def routing_numbers(self):
        """Gets the routing_numbers of this InstitutionsGetRequestOptions.  # noqa: E501

        Specify an array of routing numbers to filter institutions.  # noqa: E501

        :return: The routing_numbers of this InstitutionsGetRequestOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._routing_numbers

    @routing_numbers.setter
    def routing_numbers(self, routing_numbers):
        """Sets the routing_numbers of this InstitutionsGetRequestOptions.

        Specify an array of routing numbers to filter institutions.  # noqa: E501

        :param routing_numbers: The routing_numbers of this InstitutionsGetRequestOptions.  # noqa: E501
        :type routing_numbers: list[str]
        """

        self._routing_numbers = routing_numbers

    @property
    def oauth(self):
        """Gets the oauth of this InstitutionsGetRequestOptions.  # noqa: E501

        Limit results to institutions with or without OAuth login flows. This is primarily relevant to institutions with European country codes.  # noqa: E501

        :return: The oauth of this InstitutionsGetRequestOptions.  # noqa: E501
        :rtype: bool
        """
        return self._oauth

    @oauth.setter
    def oauth(self, oauth):
        """Sets the oauth of this InstitutionsGetRequestOptions.

        Limit results to institutions with or without OAuth login flows. This is primarily relevant to institutions with European country codes.  # noqa: E501

        :param oauth: The oauth of this InstitutionsGetRequestOptions.  # noqa: E501
        :type oauth: bool
        """

        self._oauth = oauth

    @property
    def include_optional_metadata(self):
        """Gets the include_optional_metadata of this InstitutionsGetRequestOptions.  # noqa: E501

        When `true`, return the institution's homepage URL, logo and primary brand color.   Note that Plaid does not own any of the logos shared by the API, and that by accessing or using these logos, you agree that you are doing so at your own risk and will, if necessary, obtain all required permissions from the appropriate rights holders and adhere to any applicable usage guidelines. Plaid disclaims all express or implied warranties with respect to the logos.  # noqa: E501

        :return: The include_optional_metadata of this InstitutionsGetRequestOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_optional_metadata

    @include_optional_metadata.setter
    def include_optional_metadata(self, include_optional_metadata):
        """Sets the include_optional_metadata of this InstitutionsGetRequestOptions.

        When `true`, return the institution's homepage URL, logo and primary brand color.   Note that Plaid does not own any of the logos shared by the API, and that by accessing or using these logos, you agree that you are doing so at your own risk and will, if necessary, obtain all required permissions from the appropriate rights holders and adhere to any applicable usage guidelines. Plaid disclaims all express or implied warranties with respect to the logos.  # noqa: E501

        :param include_optional_metadata: The include_optional_metadata of this InstitutionsGetRequestOptions.  # noqa: E501
        :type include_optional_metadata: bool
        """

        self._include_optional_metadata = include_optional_metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstitutionsGetRequestOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InstitutionsGetRequestOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class AccountSubtype(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    _401A = "401a"
    _401K = "401k"
    _403B = "403B"
    _457B = "457b"
    _529 = "529"
    BROKERAGE = "brokerage"
    CASH_ISA = "cash isa"
    EDUCATION_SAVINGS_ACCOUNT = "education savings account"
    GIC = "gic"
    HEALTH_REIMBURSEMENT_ARRANGEMENT = "health reimbursement arrangement"
    HSA = "hsa"
    ISA = "isa"
    IRA = "ira"
    LIF = "lif"
    LIRA = "lira"
    LRIF = "lrif"
    LRSP = "lrsp"
    NON_TAXABLE_BROKERAGE_ACCOUNT = "non-taxable brokerage account"
    OTHER = "other"
    PRIF = "prif"
    RDSP = "rdsp"
    RESP = "resp"
    RLIF = "rlif"
    RRIF = "rrif"
    PENSION = "pension"
    PROFIT_SHARING_PLAN = "profit sharing plan"
    RETIREMENT = "retirement"
    ROTH = "roth"
    ROTH_401K = "roth 401k"
    RRSP = "rrsp"
    SEP_IRA = "sep ira"
    SIMPLE_IRA = "simple ira"
    SIPP = "sipp"
    STOCK_PLAN = "stock plan"
    THRIFT_SAVINGS_PLAN = "thrift savings plan"
    TFSA = "tfsa"
    TRUST = "trust"
    UGMA = "ugma"
    UTMA = "utma"
    VARIABLE_ANNUITY = "variable annuity"
    CREDIT_CARD = "credit card"
    PAYPAL = "paypal"
    CD = "cd"
    CHECKING = "checking"
    SAVINGS = "savings"
    MONEY_MARKET = "money market"
    PREPAID = "prepaid"
    AUTO = "auto"
    COMMERCIAL = "commercial"
    CONSTRUCTION = "construction"
    CONSUMER = "consumer"
    HOME = "home"
    HOME_EQUITY = "home equity"
    LOAN = "loan"
    MORTGAGE = "mortgage"
    OVERDRAFT = "overdraft"
    LINE_OF_CREDIT = "line of credit"
    STUDENT = "student"
    CASH_MANAGEMENT = "cash management"
    KEOGH = "keogh"
    MUTUAL_FUND = "mutual fund"
    RECURRING = "recurring"
    REWARDS = "rewards"
    SAFE_DEPOSIT = "safe deposit"
    SARSEP = "sarsep"

    allowable_values = [_401A, _401K, _403B, _457B, _529, BROKERAGE, CASH_ISA, EDUCATION_SAVINGS_ACCOUNT, GIC, HEALTH_REIMBURSEMENT_ARRANGEMENT, HSA, ISA, IRA, LIF, LIRA, LRIF, LRSP, NON_TAXABLE_BROKERAGE_ACCOUNT, OTHER, PRIF, RDSP, RESP, RLIF, RRIF, PENSION, PROFIT_SHARING_PLAN, RETIREMENT, ROTH, ROTH_401K, RRSP, SEP_IRA, SIMPLE_IRA, SIPP, STOCK_PLAN, THRIFT_SAVINGS_PLAN, TFSA, TRUST, UGMA, UTMA, VARIABLE_ANNUITY, CREDIT_CARD, PAYPAL, CD, CHECKING, SAVINGS, MONEY_MARKET, PREPAID, AUTO, COMMERCIAL, CONSTRUCTION, CONSUMER, HOME, HOME_EQUITY, LOAN, MORTGAGE, OVERDRAFT, LINE_OF_CREDIT, STUDENT, CASH_MANAGEMENT, KEOGH, MUTUAL_FUND, RECURRING, REWARDS, SAFE_DEPOSIT, SARSEP]  # noqa: E501

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
    }

    attribute_map = {
    }

    def __init__(self, local_vars_configuration=None):  # noqa: E501
        """AccountSubtype - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountSubtype):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccountSubtype):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class AccountIdentity(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'str',
        'balances': 'AccountBalance',
        'mask': 'str',
        'name': 'str',
        'official_name': 'str',
        'type': 'AccountType',
        'subtype': 'AccountSubtype',
        'verification_status': 'str',
        'owners': 'list[Owner]'
    }

    attribute_map = {
        'account_id': 'account_id',
        'balances': 'balances',
        'mask': 'mask',
        'name': 'name',
        'official_name': 'official_name',
        'type': 'type',
        'subtype': 'subtype',
        'verification_status': 'verification_status',
        'owners': 'owners'
    }

    def __init__(self, account_id=None, balances=None, mask=None, name=None, official_name=None, type=None, subtype=None, verification_status=None, owners=None, local_vars_configuration=None):  # noqa: E501
        """AccountIdentity - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._balances = None
        self._mask = None
        self._name = None
        self._official_name = None
        self._type = None
        self._subtype = None
        self._verification_status = None
        self._owners = None
        self.discriminator = None

        self.account_id = account_id
        self.balances = balances
        self.mask = mask
        self.name = name
        self.official_name = official_name
        self.type = type
        self.subtype = subtype
        self.verification_status = verification_status
        if owners is not None:
            self.owners = owners

    @property
    def account_id(self):
        """Gets the account_id of this AccountIdentity.  # noqa: E501

        Plaid’s unique identifier for the account. This value will not change unless Plaid can't reconcile the account with the data returned by the financial institution. This may occur, for example, when the name of the account changes. If this happens a new `account_id` will be assigned to the account.   The `account_id` can also change if the `access_token` is deleted and the same credentials that were used to generate that `access_token` are used to generate a new `access_token` on a later date. In that case, the new `account_id` will be different from the old `account_id`.  Like all Plaid identifiers, the `account_id` is case sensitive.  # noqa: E501

        :return: The account_id of this AccountIdentity.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this AccountIdentity.

        Plaid’s unique identifier for the account. This value will not change unless Plaid can't reconcile the account with the data returned by the financial institution. This may occur, for example, when the name of the account changes. If this happens a new `account_id` will be assigned to the account.   The `account_id` can also change if the `access_token` is deleted and the same credentials that were used to generate that `access_token` are used to generate a new `access_token` on a later date. In that case, the new `account_id` will be different from the old `account_id`.  Like all Plaid identifiers, the `account_id` is case sensitive.  # noqa: E501

        :param account_id: The account_id of this AccountIdentity.  # noqa: E501
        :type account_id: str
        """
        if self.local_vars_configuration.client_side_validation and account_id is None:  # noqa: E501
            raise ValueError("Invalid value for `account_id`, must not be `None`")  # noqa: E501

        self._account_id = account_id

    @property
    def balances(self):
        """Gets the balances of this AccountIdentity.  # noqa: E501


        :return: The balances of this AccountIdentity.  # noqa: E501
        :rtype: AccountBalance
        """
        return self._balances

    @balances.setter
    def balances(self, balances):
        """Sets the balances of this AccountIdentity.


        :param balances: The balances of this AccountIdentity.  # noqa: E501
        :type balances: AccountBalance
        """
        if self.local_vars_configuration.client_side_validation and balances is None:  # noqa: E501
            raise ValueError("Invalid value for `balances`, must not be `None`")  # noqa: E501

        self._balances = balances

    @property
    def mask(self):
        """Gets the mask of this AccountIdentity.  # noqa: E501

        The last 2-4 alphanumeric characters of an account's official account number. Note that the mask may be non-unique between an Item's accounts, and it may also not match the mask that the bank displays to the user.  # noqa: E501

        :return: The mask of this AccountIdentity.  # noqa: E501
        :rtype: str
        """
        return self._mask

    @mask.setter
    def mask(self, mask):
        """Sets the mask of this AccountIdentity.

        The last 2-4 alphanumeric characters of an account's official account number. Note that the mask may be non-unique between an Item's accounts, and it may also not match the mask that the bank displays to the user.  # noqa: E501

        :param mask: The mask of this AccountIdentity.  # noqa: E501
        :type mask: str
        """

        self._mask = mask

    @property
    def name(self):
        """Gets the name of this AccountIdentity.  # noqa: E501

        The name of the account, either assigned by the user or by the financial institution itself  # noqa: E501

        :return: The name of this AccountIdentity.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AccountIdentity.

        The name of the account, either assigned by the user or by the financial institution itself  # noqa: E501

        :param name: The name of this AccountIdentity.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def official_name(self):
        """Gets the official_name of this AccountIdentity.  # noqa: E501

        The official name of the account as given by the financial institution  # noqa: E501

        :return: The official_name of this AccountIdentity.  # noqa: E501
        :rtype: str
        """
        return self._official_name

    @official_name.setter
    def official_name(self, official_name):
        """Sets the official_name of this AccountIdentity.

        The official name of the account as given by the financial institution  # noqa: E501

        :param official_name: The official_name of this AccountIdentity.  # noqa: E501
        :type official_name: str
        """

        self._official_name = official_name

    @property
    def type(self):
        """Gets the type of this AccountIdentity.  # noqa: E501


        :return: The type of this AccountIdentity.  # noqa: E501
        :rtype: AccountType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this AccountIdentity.


        :param type: The type of this AccountIdentity.  # noqa: E501
        :type type: AccountType
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def subtype(self):
        """Gets the subtype of this AccountIdentity.  # noqa: E501


        :return: The subtype of this AccountIdentity.  # noqa: E501
        :rtype: AccountSubtype
        """
        return self._subtype

    @subtype.setter
    def subtype(self, subtype):
        """Sets the subtype of this AccountIdentity.


        :param subtype: The subtype of this AccountIdentity.  # noqa: E501
        :type subtype: AccountSubtype
        """
        if self.local_vars_configuration.client_side_validation and subtype is None:  # noqa: E501
            raise ValueError("Invalid value for `subtype`, must not be `None`")  # noqa: E501

        self._subtype = subtype

    @property
    def verification_status(self):
        """Gets the verification_status of this AccountIdentity.  # noqa: E501

        The current verification status of an Auth Item initiated through Automated or Manual micro-deposits.  Returned for Auth Items only.   `pending_automatic_verification`: The Item is pending automatic verification  `pending_manual_verification`: The Item is pending manual micro-deposit verification. Items remain in this state until the user successfully verifies the two amounts.  `automatically_verified`: The Item has successfully been automatically verified   `manually_verified`: The Item has successfully been manually verified  `verification_expired`: Plaid was unable to automatically verify the deposit within 7 calendar days and will no longer attempt to validate the Item. Users may retry by submitting their information again through Link.  `verification_failed`: The Item failed manual microdeposit verification because the user exhausted all 3 verification attempts. Users may retry by submitting their information again through Link.     # noqa: E501

        :return: The verification_status of this AccountIdentity.  # noqa: E501
        :rtype: str
        """
        return self._verification_status

    @verification_status.setter
    def verification_status(self, verification_status):
        """Sets the verification_status of this AccountIdentity.

        The current verification status of an Auth Item initiated through Automated or Manual micro-deposits.  Returned for Auth Items only.   `pending_automatic_verification`: The Item is pending automatic verification  `pending_manual_verification`: The Item is pending manual micro-deposit verification. Items remain in this state until the user successfully verifies the two amounts.  `automatically_verified`: The Item has successfully been automatically verified   `manually_verified`: The Item has successfully been manually verified  `verification_expired`: Plaid was unable to automatically verify the deposit within 7 calendar days and will no longer attempt to validate the Item. Users may retry by submitting their information again through Link.  `verification_failed`: The Item failed manual microdeposit verification because the user exhausted all 3 verification attempts. Users may retry by submitting their information again through Link.     # noqa: E501

        :param verification_status: The verification_status of this AccountIdentity.  # noqa: E501
        :type verification_status: str
        """
        allowed_values = [None,"pending_automatic_verification", "pending_manual_verification", "manually_verified", "verification_expired", "verification_failed"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and verification_status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `verification_status` ({0}), must be one of {1}"  # noqa: E501
                .format(verification_status, allowed_values)
            )

        self._verification_status = verification_status

    @property
    def owners(self):
        """Gets the owners of this AccountIdentity.  # noqa: E501

        Data returned by the financial institution about the account owner or owners. Only returned by Identity or Assets endpoints. Multiple owners on a single account will be represented in the same `owner` object, not in multiple owner objects within the array.  # noqa: E501

        :return: The owners of this AccountIdentity.  # noqa: E501
        :rtype: list[Owner]
        """
        return self._owners

    @owners.setter
    def owners(self, owners):
        """Sets the owners of this AccountIdentity.

        Data returned by the financial institution about the account owner or owners. Only returned by Identity or Assets endpoints. Multiple owners on a single account will be represented in the same `owner` object, not in multiple owner objects within the array.  # noqa: E501

        :param owners: The owners of this AccountIdentity.  # noqa: E501
        :type owners: list[Owner]
        """

        self._owners = owners

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountIdentity):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccountIdentity):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class PaymentMeta(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'reference_number': 'str',
        'ppd_id': 'str',
        'payee': 'str',
        'by_order_of': 'str',
        'payer': 'str',
        'payment_method': 'str',
        'payment_processor': 'str',
        'reason': 'str'
    }

    attribute_map = {
        'reference_number': 'reference_number',
        'ppd_id': 'ppd_id',
        'payee': 'payee',
        'by_order_of': 'by_order_of',
        'payer': 'payer',
        'payment_method': 'payment_method',
        'payment_processor': 'payment_processor',
        'reason': 'reason'
    }

    def __init__(self, reference_number=None, ppd_id=None, payee=None, by_order_of=None, payer=None, payment_method=None, payment_processor=None, reason=None, local_vars_configuration=None):  # noqa: E501
        """PaymentMeta - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._reference_number = None
        self._ppd_id = None
        self._payee = None
        self._by_order_of = None
        self._payer = None
        self._payment_method = None
        self._payment_processor = None
        self._reason = None
        self.discriminator = None

        self.reference_number = reference_number
        self.ppd_id = ppd_id
        self.payee = payee
        self.by_order_of = by_order_of
        self.payer = payer
        self.payment_method = payment_method
        self.payment_processor = payment_processor
        self.reason = reason

    @property
    def reference_number(self):
        """Gets the reference_number of this PaymentMeta.  # noqa: E501

        The transaction reference number supplied by the financial institution.  # noqa: E501

        :return: The reference_number of this PaymentMeta.  # noqa: E501
        :rtype: str
        """
        return self._reference_number

    @reference_number.setter
    def reference_number(self, reference_number):
        """Sets the reference_number of this PaymentMeta.

        The transaction reference number supplied by the financial institution.  # noqa: E501

        :param reference_number: The reference_number of this PaymentMeta.  # noqa: E501
        :type reference_number: str
        """

        self._reference_number = reference_number

    @property
    def ppd_id(self):
        """Gets the ppd_id of this PaymentMeta.  # noqa: E501

        The ACH PPD ID for the payer.  # noqa: E501

        :return: The ppd_id of this PaymentMeta.  # noqa: E501
        :rtype: str
        """
        return self._ppd_id

    @ppd_id.setter
    def ppd_id(self, ppd_id):
        """Sets the ppd_id of this PaymentMeta.

        The ACH PPD ID for the payer.  # noqa: E501

        :param ppd_id: The ppd_id of this PaymentMeta.  # noqa: E501
        :type ppd_id: str
        """

        self._ppd_id = ppd_id

    @property
    def payee(self):
        """Gets the payee of this PaymentMeta.  # noqa: E501

        For transfers, the party that is receiving the transaction.  # noqa: E501

        :return: The payee of this PaymentMeta.  # noqa: E501
        :rtype: str
        """
        return self._payee

    @payee.setter
    def payee(self, payee):
        """Sets the payee of this PaymentMeta.

        For transfers, the party that is receiving the transaction.  # noqa: E501

        :param payee: The payee of this PaymentMeta.  # noqa: E501
        :type payee: str
        """

        self._payee = payee

    @property
    def by_order_of(self):
        """Gets the by_order_of of this PaymentMeta.  # noqa: E501

        The party initiating a wire transfer. Will be `null` if the transaction is not a wire transfer.  # noqa: E501

        :return: The by_order_of of this PaymentMeta.  # noqa: E501
        :rtype: str
        """
        return self._by_order_of

    @by_order_of.setter
    def by_order_of(self, by_order_of):
        """Sets the by_order_of of this PaymentMeta.

        The party initiating a wire transfer. Will be `null` if the transaction is not a wire transfer.  # noqa: E501

        :param by_order_of: The by_order_of of this PaymentMeta.  # noqa: E501
        :type by_order_of: str
        """

        self._by_order_of = by_order_of

    @property
    def payer(self):
        """Gets the payer of this PaymentMeta.  # noqa: E501

        For transfers, the party that is paying the transaction.  # noqa: E501

        :return: The payer of this PaymentMeta.  # noqa: E501
        :rtype: str
        """
        return self._payer

    @payer.setter
    def payer(self, payer):
        """Sets the payer of this PaymentMeta.

        For transfers, the party that is paying the transaction.  # noqa: E501

        :param payer: The payer of this PaymentMeta.  # noqa: E501
        :type payer: str
        """

        self._payer = payer

    @property
    def payment_method(self):
        """Gets the payment_method of this PaymentMeta.  # noqa: E501

        The type of transfer, e.g. 'ACH'  # noqa: E501

        :return: The payment_method of this PaymentMeta.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this PaymentMeta.

        The type of transfer, e.g. 'ACH'  # noqa: E501

        :param payment_method: The payment_method of this PaymentMeta.  # noqa: E501
        :type payment_method: str
        """

        self._payment_method = payment_method

    @property
    def payment_processor(self):
        """Gets the payment_processor of this PaymentMeta.  # noqa: E501

        The name of the payment processor  # noqa: E501

        :return: The payment_processor of this PaymentMeta.  # noqa: E501
        :rtype: str
        """
        return self._payment_processor

    @payment_processor.setter
    def payment_processor(self, payment_processor):
        """Sets the payment_processor of this PaymentMeta.

        The name of the payment processor  # noqa: E501

        :param payment_processor: The payment_processor of this PaymentMeta.  # noqa: E501
        :type payment_processor: str
        """

        self._payment_processor = payment_processor

    @property
    def reason(self):
        """Gets the reason of this PaymentMeta.  # noqa: E501

        The payer-supplied description of the transfer.  # noqa: E501

        :return: The reason of this PaymentMeta.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this PaymentMeta.

        The payer-supplied description of the transfer.  # noqa: E501

        :param reason: The reason of this PaymentMeta.  # noqa: E501
        :type reason: str
        """

        self._reason = reason

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentMeta):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PaymentMeta):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class Category(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'category_id': 'str',
        'group': 'str',
        'hierarchy': 'list[str]'
    }

    attribute_map = {
        'category_id': 'category_id',
        'group': 'group',
        'hierarchy': 'hierarchy'
    }

    def __init__(self, category_id=None, group=None, hierarchy=None, local_vars_configuration=None):  # noqa: E501
        """Category - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._category_id = None
        self._group = None
        self._hierarchy = None
        self.discriminator = None

        if category_id is not None:
            self.category_id = category_id
        if group is not None:
            self.group = group
        if hierarchy is not None:
            self.hierarchy = hierarchy

    @property
    def category_id(self):
        """Gets the category_id of this Category.  # noqa: E501

        An identifying number for the category. `category_id` is a Plaid-specific identifier and does not necessarily correspond to merchant category codes.  # noqa: E501

        :return: The category_id of this Category.  # noqa: E501
        :rtype: str
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """Sets the category_id of this Category.

        An identifying number for the category. `category_id` is a Plaid-specific identifier and does not necessarily correspond to merchant category codes.  # noqa: E501

        :param category_id: The category_id of this Category.  # noqa: E501
        :type category_id: str
        """

        self._category_id = category_id

    @property
    def group(self):
        """Gets the group of this Category.  # noqa: E501

        `place` for physical transactions or `special` for other transactions such as bank charges.  # noqa: E501

        :return: The group of this Category.  # noqa: E501
        :rtype: str
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this Category.

        `place` for physical transactions or `special` for other transactions such as bank charges.  # noqa: E501

        :param group: The group of this Category.  # noqa: E501
        :type group: str
        """

        self._group = group

    @property
    def hierarchy(self):
        """Gets the hierarchy of this Category.  # noqa: E501

        A hierarchical array of the categories to which this `category_id` belongs.  # noqa: E501

        :return: The hierarchy of this Category.  # noqa: E501
        :rtype: list[str]
        """
        return self._hierarchy

    @hierarchy.setter
    def hierarchy(self, hierarchy):
        """Sets the hierarchy of this Category.

        A hierarchical array of the categories to which this `category_id` belongs.  # noqa: E501

        :param hierarchy: The hierarchy of this Category.  # noqa: E501
        :type hierarchy: list[str]
        """

        self._hierarchy = hierarchy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Category):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Category):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class Item(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'item_id': 'str',
        'institution_id': 'str',
        'webhook': 'str',
        'error': 'Error',
        'available_products': 'list[Products]',
        'billed_products': 'list[Products]',
        'consent_expiration_time': 'str'
    }

    attribute_map = {
        'item_id': 'item_id',
        'institution_id': 'institution_id',
        'webhook': 'webhook',
        'error': 'error',
        'available_products': 'available_products',
        'billed_products': 'billed_products',
        'consent_expiration_time': 'consent_expiration_time'
    }

    def __init__(self, item_id=None, institution_id=None, webhook=None, error=None, available_products=None, billed_products=None, consent_expiration_time=None, local_vars_configuration=None):  # noqa: E501
        """Item - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._item_id = None
        self._institution_id = None
        self._webhook = None
        self._error = None
        self._available_products = None
        self._billed_products = None
        self._consent_expiration_time = None
        self.discriminator = None

        if item_id is not None:
            self.item_id = item_id
        self.institution_id = institution_id
        self.webhook = webhook
        self.error = error
        if available_products is not None:
            self.available_products = available_products
        if billed_products is not None:
            self.billed_products = billed_products
        self.consent_expiration_time = consent_expiration_time

    @property
    def item_id(self):
        """Gets the item_id of this Item.  # noqa: E501

        The Plaid Item ID. The `item_id` is always unique; linking the same account at the same institution twice will result in two Items with different `item_id` values. Like all Plaid identifiers, the `item_id` is case-sensitive.  # noqa: E501

        :return: The item_id of this Item.  # noqa: E501
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this Item.

        The Plaid Item ID. The `item_id` is always unique; linking the same account at the same institution twice will result in two Items with different `item_id` values. Like all Plaid identifiers, the `item_id` is case-sensitive.  # noqa: E501

        :param item_id: The item_id of this Item.  # noqa: E501
        :type item_id: str
        """

        self._item_id = item_id

    @property
    def institution_id(self):
        """Gets the institution_id of this Item.  # noqa: E501

        The Plaid Institution ID associated with the Item. Field is `null` for Items created via Same Day Micro-deposits.  # noqa: E501

        :return: The institution_id of this Item.  # noqa: E501
        :rtype: str
        """
        return self._institution_id

    @institution_id.setter
    def institution_id(self, institution_id):
        """Sets the institution_id of this Item.

        The Plaid Institution ID associated with the Item. Field is `null` for Items created via Same Day Micro-deposits.  # noqa: E501

        :param institution_id: The institution_id of this Item.  # noqa: E501
        :type institution_id: str
        """

        self._institution_id = institution_id

    @property
    def webhook(self):
        """Gets the webhook of this Item.  # noqa: E501

        The URL registered to receive webhooks for the Item.  # noqa: E501

        :return: The webhook of this Item.  # noqa: E501
        :rtype: str
        """
        return self._webhook

    @webhook.setter
    def webhook(self, webhook):
        """Sets the webhook of this Item.

        The URL registered to receive webhooks for the Item.  # noqa: E501

        :param webhook: The webhook of this Item.  # noqa: E501
        :type webhook: str
        """

        self._webhook = webhook

    @property
    def error(self):
        """Gets the error of this Item.  # noqa: E501


        :return: The error of this Item.  # noqa: E501
        :rtype: Error
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this Item.


        :param error: The error of this Item.  # noqa: E501
        :type error: Error
        """

        self._error = error

    @property
    def available_products(self):
        """Gets the available_products of this Item.  # noqa: E501

        A list of products available for the Item that have not yet been accessed.  # noqa: E501

        :return: The available_products of this Item.  # noqa: E501
        :rtype: list[Products]
        """
        return self._available_products

    @available_products.setter
    def available_products(self, available_products):
        """Sets the available_products of this Item.

        A list of products available for the Item that have not yet been accessed.  # noqa: E501

        :param available_products: The available_products of this Item.  # noqa: E501
        :type available_products: list[Products]
        """

        self._available_products = available_products

    @property
    def billed_products(self):
        """Gets the billed_products of this Item.  # noqa: E501

        A list of products that have been billed for the Item. Note - `billed_products` is populated in all environments but only requests in Production are billed.   # noqa: E501

        :return: The billed_products of this Item.  # noqa: E501
        :rtype: list[Products]
        """
        return self._billed_products

    @billed_products.setter
    def billed_products(self, billed_products):
        """Sets the billed_products of this Item.

        A list of products that have been billed for the Item. Note - `billed_products` is populated in all environments but only requests in Production are billed.   # noqa: E501

        :param billed_products: The billed_products of this Item.  # noqa: E501
        :type billed_products: list[Products]
        """

        self._billed_products = billed_products

    @property
    def consent_expiration_time(self):
        """Gets the consent_expiration_time of this Item.  # noqa: E501

        The RFC 3339 timestamp after which the consent provided by the end user will expire. Upon consent expiration, the item will enter the `ITEM_LOGIN_REQUIRED` error state. To circumvent the `ITEM_LOGIN_REQUIRED` error and maintain continuous consent, the end user can reauthenticate via Link’s update mode in advance of the consent expiration time.  Note - This is only relevant for European institutions subject to PSD2 regulations mandating a 90-day consent window. For all other institutions, this field will be null.   # noqa: E501

        :return: The consent_expiration_time of this Item.  # noqa: E501
        :rtype: str
        """
        return self._consent_expiration_time

    @consent_expiration_time.setter
    def consent_expiration_time(self, consent_expiration_time):
        """Sets the consent_expiration_time of this Item.

        The RFC 3339 timestamp after which the consent provided by the end user will expire. Upon consent expiration, the item will enter the `ITEM_LOGIN_REQUIRED` error state. To circumvent the `ITEM_LOGIN_REQUIRED` error and maintain continuous consent, the end user can reauthenticate via Link’s update mode in advance of the consent expiration time.  Note - This is only relevant for European institutions subject to PSD2 regulations mandating a 90-day consent window. For all other institutions, this field will be null.   # noqa: E501

        :param consent_expiration_time: The consent_expiration_time of this Item.  # noqa: E501
        :type consent_expiration_time: str
        """

        self._consent_expiration_time = consent_expiration_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Item):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Item):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class Holding(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'str',
        'security_id': 'str',
        'institution_price': 'float',
        'institution_price_as_of': 'str',
        'institution_value': 'float',
        'cost_basis': 'float',
        'quantity': 'float',
        'iso_currency_code': 'str',
        'unofficial_currency_code': 'str'
    }

    attribute_map = {
        'account_id': 'account_id',
        'security_id': 'security_id',
        'institution_price': 'institution_price',
        'institution_price_as_of': 'institution_price_as_of',
        'institution_value': 'institution_value',
        'cost_basis': 'cost_basis',
        'quantity': 'quantity',
        'iso_currency_code': 'iso_currency_code',
        'unofficial_currency_code': 'unofficial_currency_code'
    }

    def __init__(self, account_id=None, security_id=None, institution_price=None, institution_price_as_of=None, institution_value=None, cost_basis=None, quantity=None, iso_currency_code=None, unofficial_currency_code=None, local_vars_configuration=None):  # noqa: E501
        """Holding - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._security_id = None
        self._institution_price = None
        self._institution_price_as_of = None
        self._institution_value = None
        self._cost_basis = None
        self._quantity = None
        self._iso_currency_code = None
        self._unofficial_currency_code = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if security_id is not None:
            self.security_id = security_id
        if institution_price is not None:
            self.institution_price = institution_price
        self.institution_price_as_of = institution_price_as_of
        if institution_value is not None:
            self.institution_value = institution_value
        self.cost_basis = cost_basis
        if quantity is not None:
            self.quantity = quantity
        self.iso_currency_code = iso_currency_code
        self.unofficial_currency_code = unofficial_currency_code

    @property
    def account_id(self):
        """Gets the account_id of this Holding.  # noqa: E501

        The Plaid `account_id` associated with the holding.  # noqa: E501

        :return: The account_id of this Holding.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this Holding.

        The Plaid `account_id` associated with the holding.  # noqa: E501

        :param account_id: The account_id of this Holding.  # noqa: E501
        :type account_id: str
        """

        self._account_id = account_id

    @property
    def security_id(self):
        """Gets the security_id of this Holding.  # noqa: E501

        The Plaid `security_id` associated with the holding.  # noqa: E501

        :return: The security_id of this Holding.  # noqa: E501
        :rtype: str
        """
        return self._security_id

    @security_id.setter
    def security_id(self, security_id):
        """Sets the security_id of this Holding.

        The Plaid `security_id` associated with the holding.  # noqa: E501

        :param security_id: The security_id of this Holding.  # noqa: E501
        :type security_id: str
        """

        self._security_id = security_id

    @property
    def institution_price(self):
        """Gets the institution_price of this Holding.  # noqa: E501

        The last price given by the institution for this security.  # noqa: E501

        :return: The institution_price of this Holding.  # noqa: E501
        :rtype: float
        """
        return self._institution_price

    @institution_price.setter
    def institution_price(self, institution_price):
        """Sets the institution_price of this Holding.

        The last price given by the institution for this security.  # noqa: E501

        :param institution_price: The institution_price of this Holding.  # noqa: E501
        :type institution_price: float
        """

        self._institution_price = institution_price

    @property
    def institution_price_as_of(self):
        """Gets the institution_price_as_of of this Holding.  # noqa: E501

        The date at which `institution_price` was current.  # noqa: E501

        :return: The institution_price_as_of of this Holding.  # noqa: E501
        :rtype: str
        """
        return self._institution_price_as_of

    @institution_price_as_of.setter
    def institution_price_as_of(self, institution_price_as_of):
        """Sets the institution_price_as_of of this Holding.

        The date at which `institution_price` was current.  # noqa: E501

        :param institution_price_as_of: The institution_price_as_of of this Holding.  # noqa: E501
        :type institution_price_as_of: str
        """

        self._institution_price_as_of = institution_price_as_of

    @property
    def institution_value(self):
        """Gets the institution_value of this Holding.  # noqa: E501

        The value of the holding, as reported by the institution.  # noqa: E501

        :return: The institution_value of this Holding.  # noqa: E501
        :rtype: float
        """
        return self._institution_value

    @institution_value.setter
    def institution_value(self, institution_value):
        """Sets the institution_value of this Holding.

        The value of the holding, as reported by the institution.  # noqa: E501

        :param institution_value: The institution_value of this Holding.  # noqa: E501
        :type institution_value: float
        """

        self._institution_value = institution_value

    @property
    def cost_basis(self):
        """Gets the cost_basis of this Holding.  # noqa: E501

        The cost basis of the holding.  # noqa: E501

        :return: The cost_basis of this Holding.  # noqa: E501
        :rtype: float
        """
        return self._cost_basis

    @cost_basis.setter
    def cost_basis(self, cost_basis):
        """Sets the cost_basis of this Holding.

        The cost basis of the holding.  # noqa: E501

        :param cost_basis: The cost_basis of this Holding.  # noqa: E501
        :type cost_basis: float
        """

        self._cost_basis = cost_basis

    @property
    def quantity(self):
        """Gets the quantity of this Holding.  # noqa: E501

        The total quantity of the asset held, as reported by the financial institution.  # noqa: E501

        :return: The quantity of this Holding.  # noqa: E501
        :rtype: float
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this Holding.

        The total quantity of the asset held, as reported by the financial institution.  # noqa: E501

        :param quantity: The quantity of this Holding.  # noqa: E501
        :type quantity: float
        """

        self._quantity = quantity

    @property
    def iso_currency_code(self):
        """Gets the iso_currency_code of this Holding.  # noqa: E501

        The ISO-4217 currency code of the holding. Always `null` if `unofficial_currency_code` is non-`null`.  # noqa: E501

        :return: The iso_currency_code of this Holding.  # noqa: E501
        :rtype: str
        """
        return self._iso_currency_code

    @iso_currency_code.setter
    def iso_currency_code(self, iso_currency_code):
        """Sets the iso_currency_code of this Holding.

        The ISO-4217 currency code of the holding. Always `null` if `unofficial_currency_code` is non-`null`.  # noqa: E501

        :param iso_currency_code: The iso_currency_code of this Holding.  # noqa: E501
        :type iso_currency_code: str
        """

        self._iso_currency_code = iso_currency_code

    @property
    def unofficial_currency_code(self):
        """Gets the unofficial_currency_code of this Holding.  # noqa: E501

        The unofficial currency code associated with the holding. Always `null` if `iso_currency_code` is non-`null`. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries.  See the [currency code schema](/docs/api/accounts#currency-code-schema) for a full listing of supported `iso_currency_code`s.   # noqa: E501

        :return: The unofficial_currency_code of this Holding.  # noqa: E501
        :rtype: str
        """
        return self._unofficial_currency_code

    @unofficial_currency_code.setter
    def unofficial_currency_code(self, unofficial_currency_code):
        """Sets the unofficial_currency_code of this Holding.

        The unofficial currency code associated with the holding. Always `null` if `iso_currency_code` is non-`null`. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries.  See the [currency code schema](/docs/api/accounts#currency-code-schema) for a full listing of supported `iso_currency_code`s.   # noqa: E501

        :param unofficial_currency_code: The unofficial_currency_code of this Holding.  # noqa: E501
        :type unofficial_currency_code: str
        """

        self._unofficial_currency_code = unofficial_currency_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Holding):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Holding):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class TransactionsGetResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'accounts': 'list[AccountBase]',
        'transactions': 'list[Transaction]',
        'total_transactions': 'int',
        'item': 'Item',
        'request_id': 'str'
    }

    attribute_map = {
        'accounts': 'accounts',
        'transactions': 'transactions',
        'total_transactions': 'total_transactions',
        'item': 'item',
        'request_id': 'request_id'
    }

    def __init__(self, accounts=None, transactions=None, total_transactions=None, item=None, request_id=None, local_vars_configuration=None):  # noqa: E501
        """TransactionsGetResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._accounts = None
        self._transactions = None
        self._total_transactions = None
        self._item = None
        self._request_id = None
        self.discriminator = None

        if accounts is not None:
            self.accounts = accounts
        if transactions is not None:
            self.transactions = transactions
        if total_transactions is not None:
            self.total_transactions = total_transactions
        if item is not None:
            self.item = item
        if request_id is not None:
            self.request_id = request_id

    @property
    def accounts(self):
        """Gets the accounts of this TransactionsGetResponse.  # noqa: E501

        An array containing the `accounts` associated with the Item for which transactions are being returned. Each transaction can be mapped to its corresponding account via the `account_id` field.  # noqa: E501

        :return: The accounts of this TransactionsGetResponse.  # noqa: E501
        :rtype: list[AccountBase]
        """
        return self._accounts

    @accounts.setter
    def accounts(self, accounts):
        """Sets the accounts of this TransactionsGetResponse.

        An array containing the `accounts` associated with the Item for which transactions are being returned. Each transaction can be mapped to its corresponding account via the `account_id` field.  # noqa: E501

        :param accounts: The accounts of this TransactionsGetResponse.  # noqa: E501
        :type accounts: list[AccountBase]
        """

        self._accounts = accounts

    @property
    def transactions(self):
        """Gets the transactions of this TransactionsGetResponse.  # noqa: E501

        An array containing transactions from the account. Transactions are returned in reverse chronological order, with the most recent at the beginning of the array. The maximum number of transactions returned is determined by the `count` parameter.  # noqa: E501

        :return: The transactions of this TransactionsGetResponse.  # noqa: E501
        :rtype: list[Transaction]
        """
        return self._transactions

    @transactions.setter
    def transactions(self, transactions):
        """Sets the transactions of this TransactionsGetResponse.

        An array containing transactions from the account. Transactions are returned in reverse chronological order, with the most recent at the beginning of the array. The maximum number of transactions returned is determined by the `count` parameter.  # noqa: E501

        :param transactions: The transactions of this TransactionsGetResponse.  # noqa: E501
        :type transactions: list[Transaction]
        """

        self._transactions = transactions

    @property
    def total_transactions(self):
        """Gets the total_transactions of this TransactionsGetResponse.  # noqa: E501

        The total number of transactions available within the date range specified. If `total_transactions` is larger than the size of the `transactions` array, more transactions are available and can be fetched via manipulating the `offset` parameter.  # noqa: E501

        :return: The total_transactions of this TransactionsGetResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_transactions

    @total_transactions.setter
    def total_transactions(self, total_transactions):
        """Sets the total_transactions of this TransactionsGetResponse.

        The total number of transactions available within the date range specified. If `total_transactions` is larger than the size of the `transactions` array, more transactions are available and can be fetched via manipulating the `offset` parameter.  # noqa: E501

        :param total_transactions: The total_transactions of this TransactionsGetResponse.  # noqa: E501
        :type total_transactions: int
        """

        self._total_transactions = total_transactions

    @property
    def item(self):
        """Gets the item of this TransactionsGetResponse.  # noqa: E501


        :return: The item of this TransactionsGetResponse.  # noqa: E501
        :rtype: Item
        """
        return self._item

    @item.setter
    def item(self, item):
        """Sets the item of this TransactionsGetResponse.


        :param item: The item of this TransactionsGetResponse.  # noqa: E501
        :type item: Item
        """

        self._item = item

    @property
    def request_id(self):
        """Gets the request_id of this TransactionsGetResponse.  # noqa: E501

        A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.  # noqa: E501

        :return: The request_id of this TransactionsGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this TransactionsGetResponse.

        A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.  # noqa: E501

        :param request_id: The request_id of this TransactionsGetResponse.  # noqa: E501
        :type request_id: str
        """

        self._request_id = request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TransactionsGetResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TransactionsGetResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class LinkTokenGetResponseMetadata(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'initial_products': 'list[Products]',
        'webhook': 'str',
        'country_codes': 'list[CountryCode]',
        'language': 'str',
        'account_filters': 'dict(str, object)',
        'redirect_uri': 'str',
        'client_name': 'str'
    }

    attribute_map = {
        'initial_products': 'initial_products',
        'webhook': 'webhook',
        'country_codes': 'country_codes',
        'language': 'language',
        'account_filters': 'account_filters',
        'redirect_uri': 'redirect_uri',
        'client_name': 'client_name'
    }

    def __init__(self, initial_products=None, webhook=None, country_codes=None, language=None, account_filters=None, redirect_uri=None, client_name=None, local_vars_configuration=None):  # noqa: E501
        """LinkTokenGetResponseMetadata - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._initial_products = None
        self._webhook = None
        self._country_codes = None
        self._language = None
        self._account_filters = None
        self._redirect_uri = None
        self._client_name = None
        self.discriminator = None

        if initial_products is not None:
            self.initial_products = initial_products
        if webhook is not None:
            self.webhook = webhook
        if country_codes is not None:
            self.country_codes = country_codes
        if language is not None:
            self.language = language
        if account_filters is not None:
            self.account_filters = account_filters
        if redirect_uri is not None:
            self.redirect_uri = redirect_uri
        if client_name is not None:
            self.client_name = client_name

    @property
    def initial_products(self):
        """Gets the initial_products of this LinkTokenGetResponseMetadata.  # noqa: E501

        The `products` specified in the `/link/token/create` call.  # noqa: E501

        :return: The initial_products of this LinkTokenGetResponseMetadata.  # noqa: E501
        :rtype: list[Products]
        """
        return self._initial_products

    @initial_products.setter
    def initial_products(self, initial_products):
        """Sets the initial_products of this LinkTokenGetResponseMetadata.

        The `products` specified in the `/link/token/create` call.  # noqa: E501

        :param initial_products: The initial_products of this LinkTokenGetResponseMetadata.  # noqa: E501
        :type initial_products: list[Products]
        """

        self._initial_products = initial_products

    @property
    def webhook(self):
        """Gets the webhook of this LinkTokenGetResponseMetadata.  # noqa: E501

        The `webhook` specified in the `/link/token/create` call.  # noqa: E501

        :return: The webhook of this LinkTokenGetResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._webhook

    @webhook.setter
    def webhook(self, webhook):
        """Sets the webhook of this LinkTokenGetResponseMetadata.

        The `webhook` specified in the `/link/token/create` call.  # noqa: E501

        :param webhook: The webhook of this LinkTokenGetResponseMetadata.  # noqa: E501
        :type webhook: str
        """

        self._webhook = webhook

    @property
    def country_codes(self):
        """Gets the country_codes of this LinkTokenGetResponseMetadata.  # noqa: E501

        The `country_codes` specified in the `/link/token/create` call.  # noqa: E501

        :return: The country_codes of this LinkTokenGetResponseMetadata.  # noqa: E501
        :rtype: list[CountryCode]
        """
        return self._country_codes

    @country_codes.setter
    def country_codes(self, country_codes):
        """Sets the country_codes of this LinkTokenGetResponseMetadata.

        The `country_codes` specified in the `/link/token/create` call.  # noqa: E501

        :param country_codes: The country_codes of this LinkTokenGetResponseMetadata.  # noqa: E501
        :type country_codes: list[CountryCode]
        """

        self._country_codes = country_codes

    @property
    def language(self):
        """Gets the language of this LinkTokenGetResponseMetadata.  # noqa: E501

        The `language` specified in the `/link/token/create` call.  # noqa: E501

        :return: The language of this LinkTokenGetResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this LinkTokenGetResponseMetadata.

        The `language` specified in the `/link/token/create` call.  # noqa: E501

        :param language: The language of this LinkTokenGetResponseMetadata.  # noqa: E501
        :type language: str
        """

        self._language = language

    @property
    def account_filters(self):
        """Gets the account_filters of this LinkTokenGetResponseMetadata.  # noqa: E501

        The `account_filters` specified in the `/link/token/create` call.  # noqa: E501

        :return: The account_filters of this LinkTokenGetResponseMetadata.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._account_filters

    @account_filters.setter
    def account_filters(self, account_filters):
        """Sets the account_filters of this LinkTokenGetResponseMetadata.

        The `account_filters` specified in the `/link/token/create` call.  # noqa: E501

        :param account_filters: The account_filters of this LinkTokenGetResponseMetadata.  # noqa: E501
        :type account_filters: dict(str, object)
        """

        self._account_filters = account_filters

    @property
    def redirect_uri(self):
        """Gets the redirect_uri of this LinkTokenGetResponseMetadata.  # noqa: E501

        The `redirect_uri` specified in the `/link/token/create` call.  # noqa: E501

        :return: The redirect_uri of this LinkTokenGetResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._redirect_uri

    @redirect_uri.setter
    def redirect_uri(self, redirect_uri):
        """Sets the redirect_uri of this LinkTokenGetResponseMetadata.

        The `redirect_uri` specified in the `/link/token/create` call.  # noqa: E501

        :param redirect_uri: The redirect_uri of this LinkTokenGetResponseMetadata.  # noqa: E501
        :type redirect_uri: str
        """

        self._redirect_uri = redirect_uri

    @property
    def client_name(self):
        """Gets the client_name of this LinkTokenGetResponseMetadata.  # noqa: E501

        The `client_name` specified in the `/link/token/create` call.  # noqa: E501

        :return: The client_name of this LinkTokenGetResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._client_name

    @client_name.setter
    def client_name(self, client_name):
        """Sets the client_name of this LinkTokenGetResponseMetadata.

        The `client_name` specified in the `/link/token/create` call.  # noqa: E501

        :param client_name: The client_name of this LinkTokenGetResponseMetadata.  # noqa: E501
        :type client_name: str
        """

        self._client_name = client_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LinkTokenGetResponseMetadata):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LinkTokenGetResponseMetadata):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class LinkTokenCreateResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'link_token': 'str',
        'expiration': 'str'
    }

    attribute_map = {
        'link_token': 'link_token',
        'expiration': 'expiration'
    }

    def __init__(self, link_token=None, expiration=None, local_vars_configuration=None):  # noqa: E501
        """LinkTokenCreateResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._link_token = None
        self._expiration = None
        self.discriminator = None

        if link_token is not None:
            self.link_token = link_token
        if expiration is not None:
            self.expiration = expiration

    @property
    def link_token(self):
        """Gets the link_token of this LinkTokenCreateResponse.  # noqa: E501

        A `link_token`, which can be supplied to Link in order to initialize it and receive a `public_token`, which can be exchanged for an `access_token`.  # noqa: E501

        :return: The link_token of this LinkTokenCreateResponse.  # noqa: E501
        :rtype: str
        """
        return self._link_token

    @link_token.setter
    def link_token(self, link_token):
        """Sets the link_token of this LinkTokenCreateResponse.

        A `link_token`, which can be supplied to Link in order to initialize it and receive a `public_token`, which can be exchanged for an `access_token`.  # noqa: E501

        :param link_token: The link_token of this LinkTokenCreateResponse.  # noqa: E501
        :type link_token: str
        """

        self._link_token = link_token

    @property
    def expiration(self):
        """Gets the expiration of this LinkTokenCreateResponse.  # noqa: E501

        The expiration date for the `link_token`, in ISO 8601 format. A `link_token` created to generate a `public_token` that will be exchanged for a new `access_token` expires after 24 hours. A `link_token` created for an existing Item (such as when updating an existing `access_token` by launching Link in update mode) expires after 30 minutes.  # noqa: E501

        :return: The expiration of this LinkTokenCreateResponse.  # noqa: E501
        :rtype: str
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """Sets the expiration of this LinkTokenCreateResponse.

        The expiration date for the `link_token`, in ISO 8601 format. A `link_token` created to generate a `public_token` that will be exchanged for a new `access_token` expires after 24 hours. A `link_token` created for an existing Item (such as when updating an existing `access_token` by launching Link in update mode) expires after 30 minutes.  # noqa: E501

        :param expiration: The expiration of this LinkTokenCreateResponse.  # noqa: E501
        :type expiration: str
        """

        self._expiration = expiration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LinkTokenCreateResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LinkTokenCreateResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class ItemStatusTransactions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'last_successful_update': 'str',
        'last_failed_update': 'str'
    }

    attribute_map = {
        'last_successful_update': 'last_successful_update',
        'last_failed_update': 'last_failed_update'
    }

    def __init__(self, last_successful_update=None, last_failed_update=None, local_vars_configuration=None):  # noqa: E501
        """ItemStatusTransactions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._last_successful_update = None
        self._last_failed_update = None
        self.discriminator = None

        self.last_successful_update = last_successful_update
        self.last_failed_update = last_failed_update

    @property
    def last_successful_update(self):
        """Gets the last_successful_update of this ItemStatusTransactions.  # noqa: E501

        ISO 8601 timestamp of the last successful transactions update for the Item. The status will update each time Plaid successfully connects with the institution, regardless of whether any new data is available in the update.  # noqa: E501

        :return: The last_successful_update of this ItemStatusTransactions.  # noqa: E501
        :rtype: str
        """
        return self._last_successful_update

    @last_successful_update.setter
    def last_successful_update(self, last_successful_update):
        """Sets the last_successful_update of this ItemStatusTransactions.

        ISO 8601 timestamp of the last successful transactions update for the Item. The status will update each time Plaid successfully connects with the institution, regardless of whether any new data is available in the update.  # noqa: E501

        :param last_successful_update: The last_successful_update of this ItemStatusTransactions.  # noqa: E501
        :type last_successful_update: str
        """

        self._last_successful_update = last_successful_update

    @property
    def last_failed_update(self):
        """Gets the last_failed_update of this ItemStatusTransactions.  # noqa: E501

        ISO 8601 timestamp of the last failed transactions update for the Item. The status will update each time Plaid fails an attempt to connect with the institution, regardless of whether any new data is available in the update.  # noqa: E501

        :return: The last_failed_update of this ItemStatusTransactions.  # noqa: E501
        :rtype: str
        """
        return self._last_failed_update

    @last_failed_update.setter
    def last_failed_update(self, last_failed_update):
        """Sets the last_failed_update of this ItemStatusTransactions.

        ISO 8601 timestamp of the last failed transactions update for the Item. The status will update each time Plaid fails an attempt to connect with the institution, regardless of whether any new data is available in the update.  # noqa: E501

        :param last_failed_update: The last_failed_update of this ItemStatusTransactions.  # noqa: E501
        :type last_failed_update: str
        """

        self._last_failed_update = last_failed_update

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemStatusTransactions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemStatusTransactions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class DepositSwitchGetResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'deposit_switch_id': 'str',
        'target_account_id': 'str',
        'target_item_id': 'str',
        'state': 'str',
        'account_has_multiple_allocations': 'bool',
        'is_allocated_remainder': 'bool',
        'percent_allocated': 'bool',
        'amount_allocated': 'bool',
        'date_created': 'str',
        'date_completed': 'str',
        'request_id': 'str'
    }

    attribute_map = {
        'deposit_switch_id': 'deposit_switch_id',
        'target_account_id': 'target_account_id',
        'target_item_id': 'target_item_id',
        'state': 'state',
        'account_has_multiple_allocations': 'account_has_multiple_allocations',
        'is_allocated_remainder': 'is_allocated_remainder',
        'percent_allocated': 'percent_allocated',
        'amount_allocated': 'amount_allocated',
        'date_created': 'date_created',
        'date_completed': 'date_completed',
        'request_id': 'request_id'
    }

    def __init__(self, deposit_switch_id=None, target_account_id=None, target_item_id=None, state=None, account_has_multiple_allocations=None, is_allocated_remainder=None, percent_allocated=None, amount_allocated=None, date_created=None, date_completed=None, request_id=None, local_vars_configuration=None):  # noqa: E501
        """DepositSwitchGetResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._deposit_switch_id = None
        self._target_account_id = None
        self._target_item_id = None
        self._state = None
        self._account_has_multiple_allocations = None
        self._is_allocated_remainder = None
        self._percent_allocated = None
        self._amount_allocated = None
        self._date_created = None
        self._date_completed = None
        self._request_id = None
        self.discriminator = None

        if deposit_switch_id is not None:
            self.deposit_switch_id = deposit_switch_id
        if target_account_id is not None:
            self.target_account_id = target_account_id
        if target_item_id is not None:
            self.target_item_id = target_item_id
        if state is not None:
            self.state = state
        self.account_has_multiple_allocations = account_has_multiple_allocations
        self.is_allocated_remainder = is_allocated_remainder
        self.percent_allocated = percent_allocated
        if amount_allocated is not None:
            self.amount_allocated = amount_allocated
        if date_created is not None:
            self.date_created = date_created
        self.date_completed = date_completed
        if request_id is not None:
            self.request_id = request_id

    @property
    def deposit_switch_id(self):
        """Gets the deposit_switch_id of this DepositSwitchGetResponse.  # noqa: E501

        The ID of the Deposit Switch  # noqa: E501

        :return: The deposit_switch_id of this DepositSwitchGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._deposit_switch_id

    @deposit_switch_id.setter
    def deposit_switch_id(self, deposit_switch_id):
        """Sets the deposit_switch_id of this DepositSwitchGetResponse.

        The ID of the Deposit Switch  # noqa: E501

        :param deposit_switch_id: The deposit_switch_id of this DepositSwitchGetResponse.  # noqa: E501
        :type deposit_switch_id: str
        """

        self._deposit_switch_id = deposit_switch_id

    @property
    def target_account_id(self):
        """Gets the target_account_id of this DepositSwitchGetResponse.  # noqa: E501

        The ID of the bank account the direct deposit was switched to  # noqa: E501

        :return: The target_account_id of this DepositSwitchGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._target_account_id

    @target_account_id.setter
    def target_account_id(self, target_account_id):
        """Sets the target_account_id of this DepositSwitchGetResponse.

        The ID of the bank account the direct deposit was switched to  # noqa: E501

        :param target_account_id: The target_account_id of this DepositSwitchGetResponse.  # noqa: E501
        :type target_account_id: str
        """

        self._target_account_id = target_account_id

    @property
    def target_item_id(self):
        """Gets the target_item_id of this DepositSwitchGetResponse.  # noqa: E501

        The ID of the Item the direct deposit was switched to.  # noqa: E501

        :return: The target_item_id of this DepositSwitchGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._target_item_id

    @target_item_id.setter
    def target_item_id(self, target_item_id):
        """Sets the target_item_id of this DepositSwitchGetResponse.

        The ID of the Item the direct deposit was switched to.  # noqa: E501

        :param target_item_id: The target_item_id of this DepositSwitchGetResponse.  # noqa: E501
        :type target_item_id: str
        """

        self._target_item_id = target_item_id

    @property
    def state(self):
        """Gets the state of this DepositSwitchGetResponse.  # noqa: E501

        The state of the deposit switch.  # noqa: E501

        :return: The state of this DepositSwitchGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this DepositSwitchGetResponse.

        The state of the deposit switch.  # noqa: E501

        :param state: The state of this DepositSwitchGetResponse.  # noqa: E501
        :type state: str
        """
        allowed_values = ["initialized", "completed", "error"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and state not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    @property
    def account_has_multiple_allocations(self):
        """Gets the account_has_multiple_allocations of this DepositSwitchGetResponse.  # noqa: E501

        When `true`, user’s direct deposit goes to multiple banks. When false, user’s direct deposit only goes to the target account. Always `null` if the Deposit Switch has not been completed.  # noqa: E501

        :return: The account_has_multiple_allocations of this DepositSwitchGetResponse.  # noqa: E501
        :rtype: bool
        """
        return self._account_has_multiple_allocations

    @account_has_multiple_allocations.setter
    def account_has_multiple_allocations(self, account_has_multiple_allocations):
        """Sets the account_has_multiple_allocations of this DepositSwitchGetResponse.

        When `true`, user’s direct deposit goes to multiple banks. When false, user’s direct deposit only goes to the target account. Always `null` if the Deposit Switch has not been completed.  # noqa: E501

        :param account_has_multiple_allocations: The account_has_multiple_allocations of this DepositSwitchGetResponse.  # noqa: E501
        :type account_has_multiple_allocations: bool
        """

        self._account_has_multiple_allocations = account_has_multiple_allocations

    @property
    def is_allocated_remainder(self):
        """Gets the is_allocated_remainder of this DepositSwitchGetResponse.  # noqa: E501

        When `true`, the target account is allocated the remainder of direct deposit after all other allocations have been deducted. When `false`, user’s direct deposit is allocated as a percent or amount. Always `null` if the Deposit Switch has not been completed.  # noqa: E501

        :return: The is_allocated_remainder of this DepositSwitchGetResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_allocated_remainder

    @is_allocated_remainder.setter
    def is_allocated_remainder(self, is_allocated_remainder):
        """Sets the is_allocated_remainder of this DepositSwitchGetResponse.

        When `true`, the target account is allocated the remainder of direct deposit after all other allocations have been deducted. When `false`, user’s direct deposit is allocated as a percent or amount. Always `null` if the Deposit Switch has not been completed.  # noqa: E501

        :param is_allocated_remainder: The is_allocated_remainder of this DepositSwitchGetResponse.  # noqa: E501
        :type is_allocated_remainder: bool
        """

        self._is_allocated_remainder = is_allocated_remainder

    @property
    def percent_allocated(self):
        """Gets the percent_allocated of this DepositSwitchGetResponse.  # noqa: E501

        The percentage of direct deposit allocated to the target account. Always `null` if the target account is not allocated a percentage or if the Deposit Switch has not been completed or if `is_allocated_remainder` is true.  # noqa: E501

        :return: The percent_allocated of this DepositSwitchGetResponse.  # noqa: E501
        :rtype: bool
        """
        return self._percent_allocated

    @percent_allocated.setter
    def percent_allocated(self, percent_allocated):
        """Sets the percent_allocated of this DepositSwitchGetResponse.

        The percentage of direct deposit allocated to the target account. Always `null` if the target account is not allocated a percentage or if the Deposit Switch has not been completed or if `is_allocated_remainder` is true.  # noqa: E501

        :param percent_allocated: The percent_allocated of this DepositSwitchGetResponse.  # noqa: E501
        :type percent_allocated: bool
        """

        self._percent_allocated = percent_allocated

    @property
    def amount_allocated(self):
        """Gets the amount_allocated of this DepositSwitchGetResponse.  # noqa: E501

        The dollar amount of direct deposit allocated to the target account. Always `null` if the target account is not allocated an amount or if the Deposit Switch has not been completed.  # noqa: E501

        :return: The amount_allocated of this DepositSwitchGetResponse.  # noqa: E501
        :rtype: bool
        """
        return self._amount_allocated

    @amount_allocated.setter
    def amount_allocated(self, amount_allocated):
        """Sets the amount_allocated of this DepositSwitchGetResponse.

        The dollar amount of direct deposit allocated to the target account. Always `null` if the target account is not allocated an amount or if the Deposit Switch has not been completed.  # noqa: E501

        :param amount_allocated: The amount_allocated of this DepositSwitchGetResponse.  # noqa: E501
        :type amount_allocated: bool
        """

        self._amount_allocated = amount_allocated

    @property
    def date_created(self):
        """Gets the date_created of this DepositSwitchGetResponse.  # noqa: E501

        ISO8601 date the Deposit Switch was created.  # noqa: E501

        :return: The date_created of this DepositSwitchGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this DepositSwitchGetResponse.

        ISO8601 date the Deposit Switch was created.  # noqa: E501

        :param date_created: The date_created of this DepositSwitchGetResponse.  # noqa: E501
        :type date_created: str
        """

        self._date_created = date_created

    @property
    def date_completed(self):
        """Gets the date_completed of this DepositSwitchGetResponse.  # noqa: E501

        ISO8601 date the Deposit Switch was completed. Always `null` if the Deposit Switch has not been completed.  # noqa: E501

        :return: The date_completed of this DepositSwitchGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._date_completed

    @date_completed.setter
    def date_completed(self, date_completed):
        """Sets the date_completed of this DepositSwitchGetResponse.

        ISO8601 date the Deposit Switch was completed. Always `null` if the Deposit Switch has not been completed.  # noqa: E501

        :param date_completed: The date_completed of this DepositSwitchGetResponse.  # noqa: E501
        :type date_completed: str
        """

        self._date_completed = date_completed

    @property
    def request_id(self):
        """Gets the request_id of this DepositSwitchGetResponse.  # noqa: E501

        A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.  # noqa: E501

        :return: The request_id of this DepositSwitchGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this DepositSwitchGetResponse.

        A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.  # noqa: E501

        :param request_id: The request_id of this DepositSwitchGetResponse.  # noqa: E501
        :type request_id: str
        """

        self._request_id = request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DepositSwitchGetResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DepositSwitchGetResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class Institution(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'institution_id': 'str',
        'name': 'str',
        'products': 'list[Products]',
        'country_codes': 'list[str]',
        'url': 'str',
        'primary_color': 'str',
        'logo': 'str',
        'routing_numbers': 'list[str]',
        'oauth': 'bool',
        'status': 'InstitutionStatus'
    }

    attribute_map = {
        'institution_id': 'institution_id',
        'name': 'name',
        'products': 'products',
        'country_codes': 'country_codes',
        'url': 'url',
        'primary_color': 'primary_color',
        'logo': 'logo',
        'routing_numbers': 'routing_numbers',
        'oauth': 'oauth',
        'status': 'status'
    }

    def __init__(self, institution_id=None, name=None, products=None, country_codes=None, url=None, primary_color=None, logo=None, routing_numbers=None, oauth=None, status=None, local_vars_configuration=None):  # noqa: E501
        """Institution - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._institution_id = None
        self._name = None
        self._products = None
        self._country_codes = None
        self._url = None
        self._primary_color = None
        self._logo = None
        self._routing_numbers = None
        self._oauth = None
        self._status = None
        self.discriminator = None

        if institution_id is not None:
            self.institution_id = institution_id
        if name is not None:
            self.name = name
        if products is not None:
            self.products = products
        if country_codes is not None:
            self.country_codes = country_codes
        self.url = url
        self.primary_color = primary_color
        self.logo = logo
        self.routing_numbers = routing_numbers
        if oauth is not None:
            self.oauth = oauth
        if status is not None:
            self.status = status

    @property
    def institution_id(self):
        """Gets the institution_id of this Institution.  # noqa: E501

        Unique identifier for the institution  # noqa: E501

        :return: The institution_id of this Institution.  # noqa: E501
        :rtype: str
        """
        return self._institution_id

    @institution_id.setter
    def institution_id(self, institution_id):
        """Sets the institution_id of this Institution.

        Unique identifier for the institution  # noqa: E501

        :param institution_id: The institution_id of this Institution.  # noqa: E501
        :type institution_id: str
        """

        self._institution_id = institution_id

    @property
    def name(self):
        """Gets the name of this Institution.  # noqa: E501

        The official name of the institution  # noqa: E501

        :return: The name of this Institution.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Institution.

        The official name of the institution  # noqa: E501

        :param name: The name of this Institution.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def products(self):
        """Gets the products of this Institution.  # noqa: E501

        A list of the Plaid products supported by the institution  # noqa: E501

        :return: The products of this Institution.  # noqa: E501
        :rtype: list[Products]
        """
        return self._products

    @products.setter
    def products(self, products):
        """Sets the products of this Institution.

        A list of the Plaid products supported by the institution  # noqa: E501

        :param products: The products of this Institution.  # noqa: E501
        :type products: list[Products]
        """

        self._products = products

    @property
    def country_codes(self):
        """Gets the country_codes of this Institution.  # noqa: E501

        A list of the Plaid products supported by the institution  # noqa: E501

        :return: The country_codes of this Institution.  # noqa: E501
        :rtype: list[str]
        """
        return self._country_codes

    @country_codes.setter
    def country_codes(self, country_codes):
        """Sets the country_codes of this Institution.

        A list of the Plaid products supported by the institution  # noqa: E501

        :param country_codes: The country_codes of this Institution.  # noqa: E501
        :type country_codes: list[str]
        """

        self._country_codes = country_codes

    @property
    def url(self):
        """Gets the url of this Institution.  # noqa: E501

        The URL for the institution's website  # noqa: E501

        :return: The url of this Institution.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Institution.

        The URL for the institution's website  # noqa: E501

        :param url: The url of this Institution.  # noqa: E501
        :type url: str
        """

        self._url = url

    @property
    def primary_color(self):
        """Gets the primary_color of this Institution.  # noqa: E501

        Hexadecimal representation of the primary color used by the institution  # noqa: E501

        :return: The primary_color of this Institution.  # noqa: E501
        :rtype: str
        """
        return self._primary_color

    @primary_color.setter
    def primary_color(self, primary_color):
        """Sets the primary_color of this Institution.

        Hexadecimal representation of the primary color used by the institution  # noqa: E501

        :param primary_color: The primary_color of this Institution.  # noqa: E501
        :type primary_color: str
        """

        self._primary_color = primary_color

    @property
    def logo(self):
        """Gets the logo of this Institution.  # noqa: E501

        Base64 encoded representation of the institution's logo  # noqa: E501

        :return: The logo of this Institution.  # noqa: E501
        :rtype: str
        """
        return self._logo

    @logo.setter
    def logo(self, logo):
        """Sets the logo of this Institution.

        Base64 encoded representation of the institution's logo  # noqa: E501

        :param logo: The logo of this Institution.  # noqa: E501
        :type logo: str
        """

        self._logo = logo

    @property
    def routing_numbers(self):
        """Gets the routing_numbers of this Institution.  # noqa: E501

        A partial list of routing numbers associated with the institution. This list is provided for the purpose of looking up institutions by routing number. It is not comprehensive and should never be used as a complete list of routing numbers for an institution.  # noqa: E501

        :return: The routing_numbers of this Institution.  # noqa: E501
        :rtype: list[str]
        """
        return self._routing_numbers

    @routing_numbers.setter
    def routing_numbers(self, routing_numbers):
        """Sets the routing_numbers of this Institution.

        A partial list of routing numbers associated with the institution. This list is provided for the purpose of looking up institutions by routing number. It is not comprehensive and should never be used as a complete list of routing numbers for an institution.  # noqa: E501

        :param routing_numbers: The routing_numbers of this Institution.  # noqa: E501
        :type routing_numbers: list[str]
        """

        self._routing_numbers = routing_numbers

    @property
    def oauth(self):
        """Gets the oauth of this Institution.  # noqa: E501

        Indicates that the institution has an OAuth login flow. This is primarily relevant to institutions with European country codes.  # noqa: E501

        :return: The oauth of this Institution.  # noqa: E501
        :rtype: bool
        """
        return self._oauth

    @oauth.setter
    def oauth(self, oauth):
        """Sets the oauth of this Institution.

        Indicates that the institution has an OAuth login flow. This is primarily relevant to institutions with European country codes.  # noqa: E501

        :param oauth: The oauth of this Institution.  # noqa: E501
        :type oauth: bool
        """

        self._oauth = oauth

    @property
    def status(self):
        """Gets the status of this Institution.  # noqa: E501


        :return: The status of this Institution.  # noqa: E501
        :rtype: InstitutionStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Institution.


        :param status: The status of this Institution.  # noqa: E501
        :type status: InstitutionStatus
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Institution):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Institution):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class PaymentInitiationAddress(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'street': 'list[str]',
        'city': 'str',
        'postal_code': 'str',
        'country': 'str'
    }

    attribute_map = {
        'street': 'street',
        'city': 'city',
        'postal_code': 'postal_code',
        'country': 'country'
    }

    def __init__(self, street=None, city=None, postal_code=None, country=None, local_vars_configuration=None):  # noqa: E501
        """PaymentInitiationAddress - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._street = None
        self._city = None
        self._postal_code = None
        self._country = None
        self.discriminator = None

        self.street = street
        self.city = city
        self.postal_code = postal_code
        self.country = country

    @property
    def street(self):
        """Gets the street of this PaymentInitiationAddress.  # noqa: E501

        An array of length 1-2 representing the street address where the recipient is located.  # noqa: E501

        :return: The street of this PaymentInitiationAddress.  # noqa: E501
        :rtype: list[str]
        """
        return self._street

    @street.setter
    def street(self, street):
        """Sets the street of this PaymentInitiationAddress.

        An array of length 1-2 representing the street address where the recipient is located.  # noqa: E501

        :param street: The street of this PaymentInitiationAddress.  # noqa: E501
        :type street: list[str]
        """
        if self.local_vars_configuration.client_side_validation and street is None:  # noqa: E501
            raise ValueError("Invalid value for `street`, must not be `None`")  # noqa: E501

        self._street = street

    @property
    def city(self):
        """Gets the city of this PaymentInitiationAddress.  # noqa: E501

        The city where the recipient is located.  # noqa: E501

        :return: The city of this PaymentInitiationAddress.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this PaymentInitiationAddress.

        The city where the recipient is located.  # noqa: E501

        :param city: The city of this PaymentInitiationAddress.  # noqa: E501
        :type city: str
        """
        if self.local_vars_configuration.client_side_validation and city is None:  # noqa: E501
            raise ValueError("Invalid value for `city`, must not be `None`")  # noqa: E501

        self._city = city

    @property
    def postal_code(self):
        """Gets the postal_code of this PaymentInitiationAddress.  # noqa: E501

        The postal code where the recipient is located.  # noqa: E501

        :return: The postal_code of this PaymentInitiationAddress.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this PaymentInitiationAddress.

        The postal code where the recipient is located.  # noqa: E501

        :param postal_code: The postal_code of this PaymentInitiationAddress.  # noqa: E501
        :type postal_code: str
        """
        if self.local_vars_configuration.client_side_validation and postal_code is None:  # noqa: E501
            raise ValueError("Invalid value for `postal_code`, must not be `None`")  # noqa: E501

        self._postal_code = postal_code

    @property
    def country(self):
        """Gets the country of this PaymentInitiationAddress.  # noqa: E501

        The ISO 3166-1 alpha-2 country code where the recipient is located.  # noqa: E501

        :return: The country of this PaymentInitiationAddress.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this PaymentInitiationAddress.

        The ISO 3166-1 alpha-2 country code where the recipient is located.  # noqa: E501

        :param country: The country of this PaymentInitiationAddress.  # noqa: E501
        :type country: str
        """
        if self.local_vars_configuration.client_side_validation and country is None:  # noqa: E501
            raise ValueError("Invalid value for `country`, must not be `None`")  # noqa: E501

        self._country = country

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentInitiationAddress):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PaymentInitiationAddress):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class ItemErrorWebhook(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'webhook_type': 'str',
        'webhook_code': 'str',
        'item_id': 'str',
        'error': 'Error'
    }

    attribute_map = {
        'webhook_type': 'webhook_type',
        'webhook_code': 'webhook_code',
        'item_id': 'item_id',
        'error': 'error'
    }

    def __init__(self, webhook_type=None, webhook_code=None, item_id=None, error=None, local_vars_configuration=None):  # noqa: E501
        """ItemErrorWebhook - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._webhook_type = None
        self._webhook_code = None
        self._item_id = None
        self._error = None
        self.discriminator = None

        if webhook_type is not None:
            self.webhook_type = webhook_type
        if webhook_code is not None:
            self.webhook_code = webhook_code
        if item_id is not None:
            self.item_id = item_id
        self.error = error

    @property
    def webhook_type(self):
        """Gets the webhook_type of this ItemErrorWebhook.  # noqa: E501

        `ITEM`  # noqa: E501

        :return: The webhook_type of this ItemErrorWebhook.  # noqa: E501
        :rtype: str
        """
        return self._webhook_type

    @webhook_type.setter
    def webhook_type(self, webhook_type):
        """Sets the webhook_type of this ItemErrorWebhook.

        `ITEM`  # noqa: E501

        :param webhook_type: The webhook_type of this ItemErrorWebhook.  # noqa: E501
        :type webhook_type: str
        """

        self._webhook_type = webhook_type

    @property
    def webhook_code(self):
        """Gets the webhook_code of this ItemErrorWebhook.  # noqa: E501

        `ERROR`  # noqa: E501

        :return: The webhook_code of this ItemErrorWebhook.  # noqa: E501
        :rtype: str
        """
        return self._webhook_code

    @webhook_code.setter
    def webhook_code(self, webhook_code):
        """Sets the webhook_code of this ItemErrorWebhook.

        `ERROR`  # noqa: E501

        :param webhook_code: The webhook_code of this ItemErrorWebhook.  # noqa: E501
        :type webhook_code: str
        """

        self._webhook_code = webhook_code

    @property
    def item_id(self):
        """Gets the item_id of this ItemErrorWebhook.  # noqa: E501

        The `item_id` of the Item associated with this webhook, warning, or error  # noqa: E501

        :return: The item_id of this ItemErrorWebhook.  # noqa: E501
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this ItemErrorWebhook.

        The `item_id` of the Item associated with this webhook, warning, or error  # noqa: E501

        :param item_id: The item_id of this ItemErrorWebhook.  # noqa: E501
        :type item_id: str
        """

        self._item_id = item_id

    @property
    def error(self):
        """Gets the error of this ItemErrorWebhook.  # noqa: E501


        :return: The error of this ItemErrorWebhook.  # noqa: E501
        :rtype: Error
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this ItemErrorWebhook.


        :param error: The error of this ItemErrorWebhook.  # noqa: E501
        :type error: Error
        """

        self._error = error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemErrorWebhook):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemErrorWebhook):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class PaymentStatusUpdateWebhook(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'webhook_type': 'str',
        'webhook_code': 'str',
        'payment_id': 'str',
        'new_payment_status': 'str',
        'old_payment_status': 'str',
        'timestamp': 'str',
        'error': 'Error'
    }

    attribute_map = {
        'webhook_type': 'webhook_type',
        'webhook_code': 'webhook_code',
        'payment_id': 'payment_id',
        'new_payment_status': 'new_payment_status',
        'old_payment_status': 'old_payment_status',
        'timestamp': 'timestamp',
        'error': 'error'
    }

    def __init__(self, webhook_type=None, webhook_code=None, payment_id=None, new_payment_status=None, old_payment_status=None, timestamp=None, error=None, local_vars_configuration=None):  # noqa: E501
        """PaymentStatusUpdateWebhook - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._webhook_type = None
        self._webhook_code = None
        self._payment_id = None
        self._new_payment_status = None
        self._old_payment_status = None
        self._timestamp = None
        self._error = None
        self.discriminator = None

        if webhook_type is not None:
            self.webhook_type = webhook_type
        if webhook_code is not None:
            self.webhook_code = webhook_code
        if payment_id is not None:
            self.payment_id = payment_id
        if new_payment_status is not None:
            self.new_payment_status = new_payment_status
        if old_payment_status is not None:
            self.old_payment_status = old_payment_status
        if timestamp is not None:
            self.timestamp = timestamp
        self.error = error

    @property
    def webhook_type(self):
        """Gets the webhook_type of this PaymentStatusUpdateWebhook.  # noqa: E501

        `PAYMENT_INITIATION`  # noqa: E501

        :return: The webhook_type of this PaymentStatusUpdateWebhook.  # noqa: E501
        :rtype: str
        """
        return self._webhook_type

    @webhook_type.setter
    def webhook_type(self, webhook_type):
        """Sets the webhook_type of this PaymentStatusUpdateWebhook.

        `PAYMENT_INITIATION`  # noqa: E501

        :param webhook_type: The webhook_type of this PaymentStatusUpdateWebhook.  # noqa: E501
        :type webhook_type: str
        """

        self._webhook_type = webhook_type

    @property
    def webhook_code(self):
        """Gets the webhook_code of this PaymentStatusUpdateWebhook.  # noqa: E501

        `PAYMENT_STATUS_UPDATE`  # noqa: E501

        :return: The webhook_code of this PaymentStatusUpdateWebhook.  # noqa: E501
        :rtype: str
        """
        return self._webhook_code

    @webhook_code.setter
    def webhook_code(self, webhook_code):
        """Sets the webhook_code of this PaymentStatusUpdateWebhook.

        `PAYMENT_STATUS_UPDATE`  # noqa: E501

        :param webhook_code: The webhook_code of this PaymentStatusUpdateWebhook.  # noqa: E501
        :type webhook_code: str
        """

        self._webhook_code = webhook_code

    @property
    def payment_id(self):
        """Gets the payment_id of this PaymentStatusUpdateWebhook.  # noqa: E501

        The `payment_id` for the payment being updated  # noqa: E501

        :return: The payment_id of this PaymentStatusUpdateWebhook.  # noqa: E501
        :rtype: str
        """
        return self._payment_id

    @payment_id.setter
    def payment_id(self, payment_id):
        """Sets the payment_id of this PaymentStatusUpdateWebhook.

        The `payment_id` for the payment being updated  # noqa: E501

        :param payment_id: The payment_id of this PaymentStatusUpdateWebhook.  # noqa: E501
        :type payment_id: str
        """

        self._payment_id = payment_id

    @property
    def new_payment_status(self):
        """Gets the new_payment_status of this PaymentStatusUpdateWebhook.  # noqa: E501

        The new status of the payment.   `PAYMENT_STATUS_INPUT_NEEDED`: This is the initial state of all payments. It indicates that the payment is waiting on user input to continue processing. A payment may re-enter this state later on if further input is needed.  `PAYMENT_STATUS_PROCESSING`: The payment is currently being processed. The payment will automatically exit this state when processing is complete.  `PAYMENT_STATUS_INITIATED`: The payment has been successfully initiated and is considered complete.   `PAYMENT_STATUS_COMPLETED`: Indicates that the standing order has been successfully established. This state is only used for standing orders.  `PAYMENT_STATUS_INSUFFICIENT_FUNDS`: The payment has failed due to insufficient funds.  `PAYMENT_STATUS_FAILED`: The payment has failed to be initiated. This error is retryable once the root cause is resolved.  `PAYMENT_STATUS_BLOCKED`: The payment has been blocked. This is a retryable error.  `PAYMENT_STATUS_UNKNOWN`: The payment status is unknown.  # noqa: E501

        :return: The new_payment_status of this PaymentStatusUpdateWebhook.  # noqa: E501
        :rtype: str
        """
        return self._new_payment_status

    @new_payment_status.setter
    def new_payment_status(self, new_payment_status):
        """Sets the new_payment_status of this PaymentStatusUpdateWebhook.

        The new status of the payment.   `PAYMENT_STATUS_INPUT_NEEDED`: This is the initial state of all payments. It indicates that the payment is waiting on user input to continue processing. A payment may re-enter this state later on if further input is needed.  `PAYMENT_STATUS_PROCESSING`: The payment is currently being processed. The payment will automatically exit this state when processing is complete.  `PAYMENT_STATUS_INITIATED`: The payment has been successfully initiated and is considered complete.   `PAYMENT_STATUS_COMPLETED`: Indicates that the standing order has been successfully established. This state is only used for standing orders.  `PAYMENT_STATUS_INSUFFICIENT_FUNDS`: The payment has failed due to insufficient funds.  `PAYMENT_STATUS_FAILED`: The payment has failed to be initiated. This error is retryable once the root cause is resolved.  `PAYMENT_STATUS_BLOCKED`: The payment has been blocked. This is a retryable error.  `PAYMENT_STATUS_UNKNOWN`: The payment status is unknown.  # noqa: E501

        :param new_payment_status: The new_payment_status of this PaymentStatusUpdateWebhook.  # noqa: E501
        :type new_payment_status: str
        """
        allowed_values = ["PAYMENT_STATUS_INPUT_NEEDED", "PAYMENT_STATUS_PROCESSING", "PAYMENT_STATUS_INITIATED", "PAYMENT_STATUS_COMPLETED", "PAYMENT_STATUS_INSUFFICIENT_FUNDS", "PAYMENT_STATUS_FAILED", "PAYMENT_STATUS_BLOCKED", "PAYMENT_STATUS_UNKNOWN"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and new_payment_status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `new_payment_status` ({0}), must be one of {1}"  # noqa: E501
                .format(new_payment_status, allowed_values)
            )

        self._new_payment_status = new_payment_status

    @property
    def old_payment_status(self):
        """Gets the old_payment_status of this PaymentStatusUpdateWebhook.  # noqa: E501

        The previous status of the payment.   `PAYMENT_STATUS_INPUT_NEEDED`: This is the initial state of all payments. It indicates that the payment is waiting on user input to continue processing. A payment may re-enter this state later on if further input is needed.  `PAYMENT_STATUS_PROCESSING`: The payment is currently being processed. The payment will automatically exit this state when processing is complete.  `PAYMENT_STATUS_INITIATED`: The payment has been successfully initiated and is considered complete.   `PAYMENT_STATUS_COMPLETED`: Indicates that the standing order has been successfully established. This state is only used for standing orders.  `PAYMENT_STATUS_INSUFFICIENT_FUNDS`: The payment has failed due to insufficient funds.  `PAYMENT_STATUS_FAILED`: The payment has failed to be initiated. This error is retryable once the root cause is resolved.  `PAYMENT_STATUS_BLOCKED`: The payment has been blocked. This is a retryable error.  `PAYMENT_STATUS_UNKNOWN`: The payment status is unknown.  # noqa: E501

        :return: The old_payment_status of this PaymentStatusUpdateWebhook.  # noqa: E501
        :rtype: str
        """
        return self._old_payment_status

    @old_payment_status.setter
    def old_payment_status(self, old_payment_status):
        """Sets the old_payment_status of this PaymentStatusUpdateWebhook.

        The previous status of the payment.   `PAYMENT_STATUS_INPUT_NEEDED`: This is the initial state of all payments. It indicates that the payment is waiting on user input to continue processing. A payment may re-enter this state later on if further input is needed.  `PAYMENT_STATUS_PROCESSING`: The payment is currently being processed. The payment will automatically exit this state when processing is complete.  `PAYMENT_STATUS_INITIATED`: The payment has been successfully initiated and is considered complete.   `PAYMENT_STATUS_COMPLETED`: Indicates that the standing order has been successfully established. This state is only used for standing orders.  `PAYMENT_STATUS_INSUFFICIENT_FUNDS`: The payment has failed due to insufficient funds.  `PAYMENT_STATUS_FAILED`: The payment has failed to be initiated. This error is retryable once the root cause is resolved.  `PAYMENT_STATUS_BLOCKED`: The payment has been blocked. This is a retryable error.  `PAYMENT_STATUS_UNKNOWN`: The payment status is unknown.  # noqa: E501

        :param old_payment_status: The old_payment_status of this PaymentStatusUpdateWebhook.  # noqa: E501
        :type old_payment_status: str
        """
        allowed_values = ["PAYMENT_STATUS_INPUT_NEEDED", "PAYMENT_STATUS_PROCESSING", "PAYMENT_STATUS_INITIATED", "PAYMENT_STATUS_COMPLETED", "PAYMENT_STATUS_INSUFFICIENT_FUNDS", "PAYMENT_STATUS_FAILED", "PAYMENT_STATUS_BLOCKED", "PAYMENT_STATUS_UNKNOWN"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and old_payment_status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `old_payment_status` ({0}), must be one of {1}"  # noqa: E501
                .format(old_payment_status, allowed_values)
            )

        self._old_payment_status = old_payment_status

    @property
    def timestamp(self):
        """Gets the timestamp of this PaymentStatusUpdateWebhook.  # noqa: E501

        The timestamp of the update, in ISO 8601 format, e.g. `\"2017-09-14T14:42:19.350Z\"`  # noqa: E501

        :return: The timestamp of this PaymentStatusUpdateWebhook.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this PaymentStatusUpdateWebhook.

        The timestamp of the update, in ISO 8601 format, e.g. `\"2017-09-14T14:42:19.350Z\"`  # noqa: E501

        :param timestamp: The timestamp of this PaymentStatusUpdateWebhook.  # noqa: E501
        :type timestamp: str
        """

        self._timestamp = timestamp

    @property
    def error(self):
        """Gets the error of this PaymentStatusUpdateWebhook.  # noqa: E501


        :return: The error of this PaymentStatusUpdateWebhook.  # noqa: E501
        :rtype: Error
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this PaymentStatusUpdateWebhook.


        :param error: The error of this PaymentStatusUpdateWebhook.  # noqa: E501
        :type error: Error
        """

        self._error = error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentStatusUpdateWebhook):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PaymentStatusUpdateWebhook):
            return True

        return self.to_dict() != other.to_dict()
